@@ -22,6 +22,7 @@
 #define __STDC_WANT_IEC_60559_ATTRIBS_EXT__ 1
 #define __STDC_WANT_IEC_60559_BFP_EXT__ 1
 #define __STDC_WANT_IEC_60559_DFP_EXT__ 1
+#define __STDC_WANT_IEC_60559_EXT__ 1
 #define __STDC_WANT_IEC_60559_FUNCS_EXT__ 1
 #define __STDC_WANT_IEC_60559_TYPES_EXT__ 1
 #define __STDC_WANT_LIB_EXT2__ 1
@@ -41,6 +42,7 @@
 #define HAVE_LIBDL 1
 #define HAVE_DIRENT_H 1
 #define HAVE__BOOL 1
+#define HAVE_STDBOOL_H 1
 #define HAVE_SYS_WAIT_H 1
 #define HAVE_GRP_H 1
 #define HAVE_FCNTL_H 1
