@@ -35,7 +35,7 @@ module RbConfig
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
   CONFIG["MKMF_VERBOSE"] = "0"
-  CONFIG["MANTYPE"] = "man"
+  CONFIG["MANTYPE"] = "doc"
   CONFIG["vendorarchhdrdir"] = "$(vendorhdrdir)/$(sitearch)"
   CONFIG["sitearchhdrdir"] = "$(sitehdrdir)/$(sitearch)"
   CONFIG["rubyarchhdrdir"] = "$(rubyhdrdir)/$(arch)"
@@ -45,7 +45,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/usr' '--sysconfdir=/etc' '--enable-shared' '--disable-rpath' 'CFLAGS=-march=x86-64  -mtune=generic -O2 -pipe' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro' 'CPPFLAGS=-D_FORTIFY_SOURCE=2' 'CXXFLAGS=-march=x86-64  -mtune=generic -O2 -pipe'"
+  CONFIG["configure_args"] = " '--prefix=/usr' '--sysconfdir=/etc' '--localstatedir=/var' '--sharedstatedir=/var/lib' '--libexecdir=/usr/lib/ruby' '--enable-shared' '--disable-rpath' '--with-dbm-type=gdbm_compat' 'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/build/ruby/src=/usr/src/debug/ruby -flto=auto' 'LDFLAGS=-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto' 'CXXFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -Wp,-D_GLIBCXX_ASSERTIONS -g -ffile-prefix-map=/build/ruby/src=/usr/src/debug/ruby -flto=auto'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -106,12 +106,12 @@ module RbConfig
   CONFIG["ENABLE_DEBUG_ENV"] = ""
   CONFIG["DLNOBJ"] = "dln.o"
   CONFIG["RJIT_SUPPORT"] = "yes"
-  CONFIG["YJIT_OBJ"] = ""
-  CONFIG["YJIT_LIBS"] = ""
+  CONFIG["YJIT_OBJ"] = "yjit.$(OBJEXT)"
+  CONFIG["YJIT_LIBS"] = "yjit/target/release/libyjit.a"
   CONFIG["CARGO_BUILD_ARGS"] = ""
-  CONFIG["YJIT_SUPPORT"] = "no"
+  CONFIG["YJIT_SUPPORT"] = "yes"
   CONFIG["CARGO"] = ""
-  CONFIG["RUSTC"] = "no"
+  CONFIG["RUSTC"] = "rustc"
   CONFIG["INSTALL_STATIC_LIBRARY"] = "no"
   CONFIG["modular_gc_dir"] = ""
   CONFIG["EXECUTABLE_EXTS"] = ""
@@ -141,10 +141,8 @@ module RbConfig
   CONFIG["CCDLFLAGS"] = "-fPIC"
   CONFIG["STATIC"] = ""
   CONFIG["ARCH_FLAG"] = ""
-  CONFIG["DLDFLAGS"] = "-Wl,-O1,--sort-common,--as-needed,-z,relro -Wl,--compress-debug-sections=zlib"
+  CONFIG["DLDFLAGS"] = "-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto -Wl,--compress-debug-sections=zlib"
   CONFIG["ALLOCA"] = ""
-  CONFIG["EGREP"] = "/usr/bin/grep -E"
-  CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["dsymutil"] = ""
   CONFIG["codesign"] = ""
   CONFIG["cleanlibs"] = ""
@@ -160,7 +158,7 @@ module RbConfig
   CONFIG["RM"] = "rm -f"
   CONFIG["PKG_CONFIG"] = "pkg-config"
   CONFIG["DOXYGEN"] = "doxygen"
-  CONFIG["DOT"] = ""
+  CONFIG["DOT"] = "dot"
   CONFIG["MKDIR_P"] = "/usr/bin/mkdir -p"
   CONFIG["INSTALL_DATA"] = "$(INSTALL) -m 644"
   CONFIG["INSTALL_SCRIPT"] = "$(INSTALL)"
@@ -171,7 +169,7 @@ module RbConfig
   CONFIG["WINDRES"] = ""
   CONFIG["ARFLAGS"] = "rcD "
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "gcc (GCC) 14.2.1 20250509\nCopyright (C) 2024 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
+  CONFIG["CC_VERSION_MESSAGE"] = "gcc (GCC) 15.2.1 20250813\nCopyright (C) 2025 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
@@ -180,11 +178,11 @@ module RbConfig
   CONFIG["GNU_LD"] = "yes"
   CONFIG["GCC"] = "yes"
   CONFIG["CPP"] = "$(CC) -E"
-  CONFIG["CXXFLAGS"] = "-march=x86-64  -mtune=generic -O2 -pipe"
+  CONFIG["CXXFLAGS"] = "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -Wp,-D_GLIBCXX_ASSERTIONS -g -ffile-prefix-map=/build/ruby/src=/usr/src/debug/ruby -flto=auto"
   CONFIG["OBJEXT"] = "o"
-  CONFIG["CPPFLAGS"] = "-D_FORTIFY_SOURCE=2 $(DEFS) $(cppflags)"
-  CONFIG["LDFLAGS"] = "-L. -Wl,-O1,--sort-common,--as-needed,-z,relro -fstack-protector-strong -rdynamic -Wl,-export-dynamic -Wl,--no-as-needed"
-  CONFIG["CFLAGS"] = "-march=x86-64  -mtune=generic -O2 -pipe -fPIC"
+  CONFIG["CPPFLAGS"] = " $(DEFS) $(cppflags)"
+  CONFIG["LDFLAGS"] = "-L. -Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto -fstack-protector-strong -rdynamic -Wl,-export-dynamic -Wl,--no-as-needed"
+  CONFIG["CFLAGS"] = "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/build/ruby/src=/usr/src/debug/ruby -flto=auto -fPIC"
   CONFIG["STRIP"] = "strip -S -x"
   CONFIG["RANLIB"] = "gcc-ranlib"
   CONFIG["OBJDUMP"] = "objdump"
@@ -215,7 +213,7 @@ module RbConfig
   CONFIG["RUBY_BASE_NAME"] = "ruby"
   CONFIG["RUBY_PROGRAM_VERSION"] = "$(MAJOR).$(MINOR).$(TEENY)"
   CONFIG["RUBY_API_VERSION"] = "$(MAJOR).$(MINOR)"
-  CONFIG["HAVE_GIT"] = "yes"
+  CONFIG["HAVE_GIT"] = "no"
   CONFIG["GIT"] = "git"
   CONFIG["cxxflags"] = ""
   CONFIG["cppflags"] = ""
@@ -241,12 +239,12 @@ module RbConfig
   CONFIG["oldincludedir"] = "/usr/include"
   CONFIG["includedir"] = "$(prefix)/include"
   CONFIG["runstatedir"] = "$(localstatedir)/run"
-  CONFIG["localstatedir"] = "$(prefix)/var"
-  CONFIG["sharedstatedir"] = "$(prefix)/com"
+  CONFIG["localstatedir"] = "$(DESTDIR)/var"
+  CONFIG["sharedstatedir"] = "$(DESTDIR)/var/lib"
   CONFIG["sysconfdir"] = "$(DESTDIR)/etc"
   CONFIG["datadir"] = "$(datarootdir)"
   CONFIG["datarootdir"] = "$(prefix)/share"
-  CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
+  CONFIG["libexecdir"] = "$(DESTDIR)/usr/lib/ruby"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
   CONFIG["exec_prefix"] = "$(prefix)"
